@@ -82,9 +82,7 @@ def from_file():
                 print('\n\033[2mPython+ Code:\033[0m\n' + python_plus_code + '\n')
                 print('\033[2mPython3 Code:\033[0m\n' + python_code + '\n')
                 print('\033[2mOutput:\033[0m')
-            d = {}
-            for line in python_code.splitlines():
-                exec(python_code, d, d)
+            exec(python_code, {}, {})
             return 0
     except Exception as e:
         print('\033[1;31mAn error occurred:', e, '\033[0m')
